pub trait MapToJavaScriptHTML<K> {
// Required methods
fn to_javascript_html_to_vec<'a, S: Display>(
&self,
variable_name: S,
output: &'a mut Vec<u8>,
) -> &'a [u8] ⓘ;
fn to_javascript_html_to_writer<S: Display, W: Write>(
&self,
variable_name: S,
output: &mut W,
) -> Result<(), Error>;
fn to_javascript_html_with_keys_to_vec<'a, S: Display, KS: ?Sized + Display + Ord + Eq + Hash>(
&self,
variable_name: S,
keys: &[&KS],
output: &'a mut Vec<u8>,
) -> &'a [u8] ⓘ
where K: Borrow<KS>;
fn to_javascript_html_with_keys_to_writer<S: Display, W: Write, KS: ?Sized + Display + Ord + Eq + Hash>(
&self,
variable_name: S,
keys: &[&KS],
output: &mut W,
) -> Result<(), Error>
where K: Borrow<KS>;
// Provided methods
fn to_javascript_html<S: Display>(&self, variable_name: S) -> String { ... }
fn to_javascript_html_to_string<'a, S: Display>(
&self,
variable_name: S,
output: &'a mut String,
) -> &'a str { ... }
fn to_javascript_html_with_keys<S: Display, KS: ?Sized + Display + Ord + Eq + Hash>(
&self,
variable_name: S,
keys: &[&KS],
) -> String
where K: Borrow<KS> { ... }
fn to_javascript_html_with_keys_to_string<'a, S: Display, KS: ?Sized + Display + Ord + Eq + Hash>(
&self,
variable_name: S,
keys: &[&KS],
output: &'a mut String,
) -> &'a str
where K: Borrow<KS> { ... }
}Expand description
Serializing a map to JavaScript code in HTML.
Required Methods
Sourcefn to_javascript_html_to_vec<'a, S: Display>(
&self,
variable_name: S,
output: &'a mut Vec<u8>,
) -> &'a [u8] ⓘ
fn to_javascript_html_to_vec<'a, S: Display>( &self, variable_name: S, output: &'a mut Vec<u8>, ) -> &'a [u8] ⓘ
Convert this map to minified JavaScript code in HTML. Write it to an existing Vec<u8> and return a u8 slice of the written HTML. Be careful of the variable_name which will not be encoded in HTML.
Sourcefn to_javascript_html_to_writer<S: Display, W: Write>(
&self,
variable_name: S,
output: &mut W,
) -> Result<(), Error>
fn to_javascript_html_to_writer<S: Display, W: Write>( &self, variable_name: S, output: &mut W, ) -> Result<(), Error>
Convert this map to minified JavaScript code in HTML. Write it to a writer. Be careful of the variable_name which will not be encoded in HTML.
Sourcefn to_javascript_html_with_keys_to_vec<'a, S: Display, KS: ?Sized + Display + Ord + Eq + Hash>(
&self,
variable_name: S,
keys: &[&KS],
output: &'a mut Vec<u8>,
) -> &'a [u8] ⓘwhere
K: Borrow<KS>,
fn to_javascript_html_with_keys_to_vec<'a, S: Display, KS: ?Sized + Display + Ord + Eq + Hash>(
&self,
variable_name: S,
keys: &[&KS],
output: &'a mut Vec<u8>,
) -> &'a [u8] ⓘwhere
K: Borrow<KS>,
Convert this map to minified JavaScript code in HTML by given keys. Write it to an existing Vec<u8> and return a u8 slice of the written HTML. If the key doesn’t exist, the output value will be undefined. Be careful of the variable_name which will not be encoded in HTML.
Sourcefn to_javascript_html_with_keys_to_writer<S: Display, W: Write, KS: ?Sized + Display + Ord + Eq + Hash>(
&self,
variable_name: S,
keys: &[&KS],
output: &mut W,
) -> Result<(), Error>where
K: Borrow<KS>,
fn to_javascript_html_with_keys_to_writer<S: Display, W: Write, KS: ?Sized + Display + Ord + Eq + Hash>(
&self,
variable_name: S,
keys: &[&KS],
output: &mut W,
) -> Result<(), Error>where
K: Borrow<KS>,
Convert this map to minified JavaScript code in HTML. Write it to a writer. If the key doesn’t exist, the output value will be undefined. Be careful of the variable_name which will not be encoded in HTML.
Provided Methods
Sourcefn to_javascript_html<S: Display>(&self, variable_name: S) -> String
fn to_javascript_html<S: Display>(&self, variable_name: S) -> String
Convert this map to minified JavaScript code in HTML. Be careful of the variable_name which will not be encoded in HTML.
Sourcefn to_javascript_html_to_string<'a, S: Display>(
&self,
variable_name: S,
output: &'a mut String,
) -> &'a str
fn to_javascript_html_to_string<'a, S: Display>( &self, variable_name: S, output: &'a mut String, ) -> &'a str
Convert this map to minified JavaScript code in HTML. Write it to an existing String and return a string slice of the written HTML. Be careful of the variable_name which will not be encoded in HTML.
Sourcefn to_javascript_html_with_keys<S: Display, KS: ?Sized + Display + Ord + Eq + Hash>(
&self,
variable_name: S,
keys: &[&KS],
) -> Stringwhere
K: Borrow<KS>,
fn to_javascript_html_with_keys<S: Display, KS: ?Sized + Display + Ord + Eq + Hash>(
&self,
variable_name: S,
keys: &[&KS],
) -> Stringwhere
K: Borrow<KS>,
Convert this map to minified JavaScript code in HTML by given keys. If the key doesn’t exist, the output value will be undefined. Be careful of the variable_name which will not be encoded in HTML.
Sourcefn to_javascript_html_with_keys_to_string<'a, S: Display, KS: ?Sized + Display + Ord + Eq + Hash>(
&self,
variable_name: S,
keys: &[&KS],
output: &'a mut String,
) -> &'a strwhere
K: Borrow<KS>,
fn to_javascript_html_with_keys_to_string<'a, S: Display, KS: ?Sized + Display + Ord + Eq + Hash>(
&self,
variable_name: S,
keys: &[&KS],
output: &'a mut String,
) -> &'a strwhere
K: Borrow<KS>,
Convert this map to minified JavaScript code in HTML by given keys. Write it to an existing String and return a string slice of the written HTML. If the key doesn’t exist, the output value will be undefined. Be careful of the variable_name which will not be encoded in HTML.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".